==> monica-3.7.0p2.tgz: www/monica/resources/lang/vi/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Hôm nay của bạn thế nào? Bạn có thể đánh giá mỗi ngày một lần.',
    'journal_come_back' => 'Cảm ơn. Quay lại vào ngày mai để đánh giá lại một ngày của bạn.',
    'journal_description' => 'Ghi chú: danh sách nhật ký liệt kê cả mục nhật ký thủ công và mục tự động như Hoạt động được thực hiện với liên hệ của bạn. Mặc dù bạn có thể xóa nhật ký thủ công, bạn sẽ phải xóa hoạt động trực tiếp ở trang liên hệ.',
    'journal_add' => 'Thêm mục nhật ký',
    'journal_edit' => 'Sửa mục nhật ký',
    'journal_empty' => 'Không có nhật ký nào',
    'journal_created_at' => 'Tạo ngày {date}',
    'journal_created_automatically' => 'Được tạo tự động',
    'journal_entry_type_journal' => 'Mục nhật ký',
    'journal_entry_type_activity' => 'Hoạt động',
    'journal_entry_rate' => 'Bạn đã đánh giá ngày của bạn.',
    'journal_add_comment' => 'Bạn muốn thêm nhận xét (không bắt buộc)?',
    'journal_show_comment' => 'Hiển thị bình luận',
    'entry_delete_success' => 'Xóa nhật ký thành công.',
    'journal_add_title' => 'Tiêu đề (không bắt buộc)',
    'journal_add_date' => 'Ngày',
    'journal_add_post' => 'Mục',
    'journal_add_cta' => 'Lưu',
    'journal_blank_cta' => 'Thêm mục nhật ký đầu tiên của bạn',
    'journal_blank_description' => 'Nhật ký cho phép bạn viết sự kiện đã xảy ra với bạn, và ghi nhớ chúng.',
    'delete_confirmation' => 'Bạn chắc chắn muốn xóa mục nhật ký này?',
];

==> monica-4.1.2p0.tgz: www/monica/resources/lang/vi/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Hôm nay của bạn thế nào? Bạn có thể đánh giá mỗi ngày một lần.',
    'journal_come_back' => 'Cảm ơn. Quay lại vào ngày mai để đánh giá lại một ngày của bạn.',
    'journal_description' => 'Ghi chú: danh sách nhật ký liệt kê cả mục nhật ký thủ công và mục tự động như Hoạt động được thực hiện với liên hệ của bạn. Mặc dù bạn có thể xóa nhật ký thủ công, bạn sẽ phải xóa hoạt động trực tiếp ở trang liên hệ.',
    'journal_add' => 'Thêm mục nhật ký',
    'journal_edit' => 'Sửa mục nhật ký',
    'journal_empty' => 'Không có nhật ký nào',
    'journal_created_at' => 'Tạo ngày {date}',
    'journal_created_automatically' => 'Được tạo tự động',
    'journal_entry_type_journal' => 'Mục nhật ký',
    'journal_entry_type_activity' => 'Hoạt động',
    'journal_entry_rate' => 'Bạn đã đánh giá ngày của bạn.',
    'journal_add_comment' => 'Bạn muốn thêm nhận xét (không bắt buộc)?',
    'journal_show_comment' => 'Hiển thị bình luận',
    'entry_delete_success' => 'Xóa nhật ký thành công.',
    'journal_add_title' => 'Tiêu đề (không bắt buộc)',
    'journal_add_date' => 'Ngày',
    'journal_add_post' => 'Mục',
    'journal_add_cta' => 'Lưu',
    'journal_blank_cta' => 'Thêm mục nhật ký đầu tiên của bạn',
    'journal_blank_description' => 'Nhật ký cho phép bạn viết sự kiện đã xảy ra với bạn, và ghi nhớ chúng.',
    'delete_confirmation' => 'Bạn chắc chắn muốn xóa mục nhật ký này?',
    'apply_filter' => 'Apply filter',
    'start_date' => 'Start Date',
    'end_date' => 'End Date',
    'per_page' => 'Per Page',
    'sort_order' => 'Sort By Created At',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
];
